--- nagios-plugins-HEAD-200411030547/plugins/check_http.c       2004-03-22 04:19:58.000000000 -0300
+++ nagios-plugins-OK/plugins/check_http.c      2004-11-03 12:58:28.000000000 -0200
@@ -26,6 +26,8 @@
 #include "netutils.h"
 #include "utils.h"

+#define INPUT_DELIMITER ";"
+
 #define HTTP_EXPECT "HTTP/1."
 enum {
        MAX_IPV4_HOSTLENGTH = 255,
@@ -102,6 +104,7 @@
 int check_critical_time = FALSE;
 char user_auth[MAX_INPUT_BUFFER] = "";
 int display_html = FALSE;
+char *http_opt_headers;
 int onredirect = STATE_OK;
 int use_ssl = FALSE;
 int verbose = FALSE;
@@ -209,6 +212,8 @@
                {"linespan", no_argument, 0, 'l'},
                {"onredirect", required_argument, 0, 'f'},
                {"certificate", required_argument, 0, 'C'},
+                {"useragent", required_argument, 0, 'A'},
+                {"header", required_argument, 0, 'k'},
                {"content-type", required_argument, 0, 'T'},
                {"min", required_argument, 0, 'm'},
                {"use-ipv4", no_argument, 0, '4'},
@@ -233,7 +238,7 @@
        }

        while (1) {
-               c = getopt_long (argc, argv, "Vvh46t:c:w:H:P:T:I:a:e:p:s:R:r:u:f:C:nlLSm:", longopts, &option);
+               c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:T:I:a:e:p:s:R:r:u:f:C:nlLSm:", longopts, &option);
                if (c == -1 || c == EOF)
                        break;

@@ -271,6 +276,12 @@
                                check_warning_time = TRUE;
                        }
                        break;
+                case 'A': /* User Agent String */
+                        asprintf (&user_agent, "User-Agent: %s", optarg);
+                        break;
+                case 'k': /* Addicional headers */
+                        http_opt_headers = strscpy (http_opt_headers, optarg);
+                        break;
                case 'L': /* show html link */
                        display_html = TRUE;
                        break;
@@ -516,6 +527,13 @@
        /* optionally send the host header info */
        if (host_name)
                asprintf (&buf, "%sHost: %s\r\n", buf, host_name);
+
+        /* optionally send any other header tag */
+        if (http_opt_headers) {
+               for ((pos = strtok(http_opt_headers, INPUT_DELIMITER )); pos; (pos = strtok(NULL, INPUT_DELIMITER)))
+                     asprintf (&buf, "%s%s\r\n", buf, pos);
+
+        }

        /* optionally send the authentication info */
        if (strlen(user_auth)) {
@@ -1170,6 +1188,10 @@
        printf (_("\
  -a, --authorization=AUTH_PAIR\n\
    Username:password on sites with basic authentication\n\
+ -A, --useragent=STRING\n\
+   String to be sent in http header as \"User Agent\"\n\
+ -k, --header=STRING\n\
+   Any other tags to be sent in http header, separeted by semicolon\n\
  -L, --link=URL\n\
    Wrap output in HTML link (obsoleted by urlize)\n\
  -f, --onredirect=<ok|warning|critical|follow>\n\
@@ -1224,8 +1246,8 @@
        printf (_("\
 Usage: %s (-H <vhost> | -I <IP-address>) [-u <uri>] [-p <port>]\n\
   [-w <warn time>] [-c <critical time>] [-t <timeout>] [-L]\n\
-  [-a auth] [-f <ok | warn | critcal | follow>] [-e <expect>]\n\
-  [-s string] [-l] [-r <regex> | -R <case-insensitive regex>]\n\
+  [-a auth] [-A string] [-k string] [-f <ok | warn | critcal | follow>]\n\
+  [-e <expect>] [-s string] [-l] [-r <regex> | -R <case-insensitive regex>]\n\
   [-P string] [-m min_pg_size] [-4|-6]\n"), progname);
        printf (_(UT_HLP_VRS), progname, progname);
 }

